@@ -1,6 +1,7 @@
 import "src/minErr.js";
 import "src/Angular.js";
 import "src/loader.js";
+import "src/shallowCopy.js";
 import "src/stringify.js";
 import "src/AngularPublic.js";
 import "src/jqLite.js";
@@ -21,6 +22,7 @@ import "src/ng/http.js";
 import "src/ng/httpBackend.js";
 import "src/ng/interpolate.js";
 import "src/ng/interval.js";
+import "src/ng/jsonpCallbacks.js";
 import "src/ng/locale.js";
 import "src/ng/location.js";
 import "src/ng/log.js";
@@ -71,7 +73,6 @@ import "src/ng/directive/ngSwitch.js";
 import "src/ng/directive/ngTransclude.js";
 import "src/ng/directive/script.js";
 import "src/ng/directive/select.js";
-import "src/ng/directive/style.js";
 import "src/ng/directive/validators.js";
 import "src/angular.bind.js";
 import "src/publishExternalApis.js";
